  function y = MatVecR0(A,x)
%
% Pre:
%    A     m-by-n matrix.
%    x     n-by-1
%
% Post:
%    y     A*x (row-oriented method)
%
   [m,n] = size(A);
   y = zeros(m,1);
   for i=1:m
      y(i) = A(i,:)*x;
   end;
